@@ -3,66 +3,67 @@ package operator
 import (
 	"time"
 
+	"k8s.io/apimachinery/pkg/api/errors"
 	utilruntime "k8s.io/apimachinery/pkg/util/runtime"
 	"k8s.io/apimachinery/pkg/util/wait"
 	appsv1informers "k8s.io/client-go/informers/apps/v1"
 	appsv1listers "k8s.io/client-go/listers/apps/v1"
-	"k8s.io/client-go/rest"
 	"k8s.io/client-go/tools/cache"
 	"k8s.io/client-go/util/workqueue"
 	"k8s.io/klog"
 
+	configv1 "github.com/openshift/api/config/v1"
 	configv1client "github.com/openshift/client-go/config/clientset/versioned/typed/config/v1"
 	configv1informers "github.com/openshift/client-go/config/informers/externalversions/config/v1"
 	configv1listers "github.com/openshift/client-go/config/listers/config/v1"
 	imageregistryv1informers "github.com/openshift/client-go/imageregistry/informers/externalversions/imageregistry/v1"
 	imageregistryv1listers "github.com/openshift/client-go/imageregistry/listers/imageregistry/v1"
 
-	"github.com/openshift/cluster-image-registry-operator/defaults"
-	"github.com/openshift/cluster-image-registry-operator/pkg/client"
+	"github.com/openshift/cluster-image-registry-operator/pkg/defaults"
 	"github.com/openshift/cluster-image-registry-operator/pkg/resource"
-	"github.com/openshift/cluster-image-registry-operator/pkg/storage"
 )
 
 type ClusterOperatorStatusController struct {
+	relatedObjects []configv1.ObjectReference
+
 	clusterOperatorClient     configv1client.ClusterOperatorsGetter
 	clusterOperatorLister     configv1listers.ClusterOperatorLister
 	imageRegistryConfigLister imageregistryv1listers.ConfigLister
+	imagePrunerLister         imageregistryv1listers.ImagePrunerLister
 	deploymentLister          appsv1listers.DeploymentNamespaceLister
 
 	cachesToSync []cache.InformerSynced
 	queue        workqueue.RateLimitingInterface
-
-	// These fields should be used only for NewGenerator
-	kubeconfig *rest.Config
-	clients    *client.Clients
-	listers    *client.Listers
 }
 
 func NewClusterOperatorStatusController(
+	relatedObjects []configv1.ObjectReference,
 	configClient configv1client.ConfigV1Interface,
 	clusterOperatorInformer configv1informers.ClusterOperatorInformer,
 	imageRegistryConfigInformer imageregistryv1informers.ConfigInformer,
+	imagePrunerInformer imageregistryv1informers.ImagePrunerInformer,
 	deploymentInformer appsv1informers.DeploymentInformer,
-	kubeconfig *rest.Config, clients *client.Clients, listers *client.Listers,
 ) *ClusterOperatorStatusController {
 	c := &ClusterOperatorStatusController{
+		relatedObjects:            relatedObjects,
 		clusterOperatorClient:     configClient,
 		clusterOperatorLister:     clusterOperatorInformer.Lister(),
 		imageRegistryConfigLister: imageRegistryConfigInformer.Lister(),
+		imagePrunerLister:         imagePrunerInformer.Lister(),
 		deploymentLister:          deploymentInformer.Lister().Deployments(defaults.ImageRegistryOperatorNamespace),
 		queue:                     workqueue.NewNamedRateLimitingQueue(workqueue.DefaultControllerRateLimiter(), "ClusterOperatorStatusController"),
-		kubeconfig:                kubeconfig,
-		clients:                   clients,
-		listers:                   listers,
 	}
 
 	clusterOperatorInformer.Informer().AddEventHandler(c.eventHandler())
-	imageRegistryConfigInformer.Informer().AddEventHandler(c.eventHandler())
-	deploymentInformer.Informer().AddEventHandler(c.eventHandler())
-
 	c.cachesToSync = append(c.cachesToSync, clusterOperatorInformer.Informer().HasSynced)
+
+	imageRegistryConfigInformer.Informer().AddEventHandler(c.eventHandler())
 	c.cachesToSync = append(c.cachesToSync, imageRegistryConfigInformer.Informer().HasSynced)
+
+	imagePrunerInformer.Informer().AddEventHandler(c.eventHandler())
+	c.cachesToSync = append(c.cachesToSync, imagePrunerInformer.Informer().HasSynced)
+
+	deploymentInformer.Informer().AddEventHandler(c.eventHandler())
 	c.cachesToSync = append(c.cachesToSync, deploymentInformer.Informer().HasSynced)
 
 	return c
@@ -107,10 +108,12 @@ func (c *ClusterOperatorStatusController) sync() error {
 	}
 	cr = cr.DeepCopy()
 
-	gen := resource.NewGenerator(c.kubeconfig, c.clients, c.listers, Parameters(defaults.ImageRegistryOperatorNamespace))
-	resources, err := gen.List(cr)
-	if err != nil && err != storage.ErrStorageNotConfigured {
-		return err
+	imagepruner, err := c.imagePrunerLister.Get("cluster")
+	if err != nil {
+		if !errors.IsNotFound(err) {
+			klog.Warningf("unable to get imagepruner: %v", err)
+		}
+		imagepruner = nil
 	}
 
 	mut := resource.NewGeneratorClusterOperator(
@@ -118,7 +121,8 @@ func (c *ClusterOperatorStatusController) sync() error {
 		c.clusterOperatorLister,
 		c.clusterOperatorClient,
 		cr,
-		resources,
+		imagepruner,
+		c.relatedObjects,
 	)
 
 	return resource.ApplyMutator(mut)
